## 0.1 Initial version

Its engine is under extraction from `yawrap` in order to make it a standalone library.

## 0.2 Sketches get mature form

The package gets shapes of final version.
`XPlant` is a proxy for exposing given node type interface.
`XML` and basic `YAML` markups are supported.
